@@ -19,7 +19,7 @@
 import os
 import re
 
-__version__ = "0.13.1"
+__version__ = "0.15"
 
 debug = bool(os.environ.get("GAUPOL_DEBUG", ""))
 re_any_tag = re.compile(r"(^[/\\_]+|<.*?>|\{.*?\})")
@@ -50,6 +50,7 @@ from gaupol import languages
 from gaupol import countries
 from gaupol import locales
 from gaupol import scripts
+from gaupol.metadata import *
 from gaupol.unittest import *
 from gaupol.calculator import *
 from gaupol.finder import *
