@@ -26,10 +26,12 @@ class ReportABugAction(gaupol.gtk.Action):
     """Submit a bug report."""
 
     def __init__(self):
+        """Initialize a ReportABugAction object."""
 
         gaupol.gtk.Action.__init__(self, "report_a_bug")
         self.props.label = _("_Report A Bug")
         self.props.tooltip = _("Submit a bug report")
+        self.action_group = "main-safe"
 
 
 class ViewAboutDialogAction(gaupol.gtk.Action):
@@ -37,11 +39,13 @@ class ViewAboutDialogAction(gaupol.gtk.Action):
     """Show information about Gaupol."""
 
     def __init__(self):
+        """Initialize a ViewAboutDialogAction object."""
 
         gaupol.gtk.Action.__init__(self, "view_about_dialog")
         self.props.label = _("_About")
         self.props.stock_id = gtk.STOCK_ABOUT
         self.props.tooltip = _("Show information about Gaupol")
+        self.action_group = "main-safe"
 
 
 __all__ = gaupol.util.get_all(dir(), r"Action$")
