@@ -26,6 +26,7 @@ class FindAndReplaceAction(gaupol.gtk.Action):
     """Search for and replace text."""
 
     def __init__(self):
+        """Initialize a FindAndReplaceAction object."""
 
         gaupol.gtk.Action.__init__(self, "find_and_replace")
         self.props.label = _("_Find And Replace\342\200\246")
@@ -33,6 +34,7 @@ class FindAndReplaceAction(gaupol.gtk.Action):
         self.props.stock_id = gtk.STOCK_FIND_AND_REPLACE
         self.props.tooltip = _("Search for and replace text")
         self.accelerator = "<Control>F"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -45,11 +47,13 @@ class FindNextAction(gaupol.gtk.Action):
     """Search forwards for same text."""
 
     def __init__(self):
+        """Initialize a FindNextAction object."""
 
         gaupol.gtk.Action.__init__(self, "find_next")
         self.props.label = _("Find _Next")
         self.props.tooltip = _("Search forwards for same text")
         self.accelerator = "<Control>G"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -63,11 +67,13 @@ class FindPreviousAction(gaupol.gtk.Action):
     """Search backwards for same text."""
 
     def __init__(self):
+        """Initialize a FindPreviousAction object."""
 
         gaupol.gtk.Action.__init__(self, "find_previous")
         self.props.label = _("Find Pre_vious")
         self.props.tooltip = _("Search backwards for same text")
         self.accelerator = "<Shift><Control>G"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
