@@ -26,10 +26,12 @@ class ConfigureSpellCheckAction(gaupol.gtk.Action):
     """Set languages and spell-check targets."""
 
     def __init__(self):
+        """Initialize a ConfigureSpellCheckAction object."""
 
         gaupol.gtk.Action.__init__(self, "configure_spell_check")
         self.props.label = _("Co_nfigure Spell-check\342\200\246")
         self.props.tooltip = _("Set language and spell-check target")
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -42,6 +44,7 @@ class CheckSpellingAction(gaupol.gtk.Action):
     """Check for incorrect spelling."""
 
     def __init__(self):
+        """Initialize a CheckSpellingAction object."""
 
         gaupol.gtk.Action.__init__(self, "check_spelling")
         self.props.label = _("_Check Spelling")
@@ -49,6 +52,7 @@ class CheckSpellingAction(gaupol.gtk.Action):
         self.props.stock_id = gtk.STOCK_SPELL_CHECK
         self.props.tooltip = _("Check for incorrect spelling")
         self.accelerator = "F7"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
@@ -63,11 +67,13 @@ class CorrectTextsAction(gaupol.gtk.Action):
     """Find and correct errors in texts."""
 
     def __init__(self):
+        """Initialize a CorrectTextsAction object."""
 
         gaupol.gtk.Action.__init__(self, "correct_texts")
         self.props.label = _("C_orrect Texts\342\200\246")
         self.props.tooltip = _("Find and correct errors in texts")
         self.accelerator = "O"
+        self.action_group = "main-unsafe"
 
     def _affirm_doable(self, application, page):
         """Raise AssertionError if action cannot be done."""
