@@ -31,7 +31,8 @@ class TestUtilityAgent(gaupol.gtk.TestCase):
 
     def test_get_action_group(self):
 
-        self.application.get_action_group("main")
+        self.application.get_action_group("main-safe")
+        self.application.get_action_group("main-unsafe")
         self.application.get_action_group("projects")
 
     def test_get_column_action(self):
@@ -39,7 +40,7 @@ class TestUtilityAgent(gaupol.gtk.TestCase):
         for field in gaupol.gtk.fields:
             self.application.get_column_action(field)
         function = self.application.get_column_action
-        self.raises(ValueError, function, None)
+        self.raises(KeyError, function, None)
 
     def test_get_current_page(self):
 
@@ -53,7 +54,7 @@ class TestUtilityAgent(gaupol.gtk.TestCase):
         for framerate in gaupol.framerates:
             self.application.get_framerate_action(framerate)
         function = self.application.get_framerate_action
-        self.raises(ValueError, function, None)
+        self.raises(KeyError, function, None)
 
     def test_get_menu_item(self):
 
@@ -66,7 +67,7 @@ class TestUtilityAgent(gaupol.gtk.TestCase):
         for mode in gaupol.modes:
             self.application.get_mode_action(mode)
         function = self.application.get_mode_action
-        self.raises(ValueError, function, None)
+        self.raises(KeyError, function, None)
 
     def test_get_target_pages(self):
 
