@@ -28,6 +28,7 @@ class _PositionShiftDialog(gaupol.gtk.GladeDialog):
     """Base class for dialogs for shifting positions."""
 
     def __init__(self, parent, application):
+        """Initialize a _PositionShiftDialog object."""
 
         gaupol.gtk.GladeDialog.__init__(self, "shift.glade")
         get_widget = self._glade_xml.get_widget
@@ -64,7 +65,7 @@ class _PositionShiftDialog(gaupol.gtk.GladeDialog):
             return gaupol.gtk.targets.CURRENT
         if self._all_radio.get_active():
             return gaupol.gtk.targets.ALL
-        raise ValueError
+        raise ValueError("Invalid target radio state")
 
     def _init_signal_handlers(self):
         """Initialize signal handlers."""
