@@ -48,7 +48,7 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
 
     __metaclass__ = gaupol.Contractual
     _max_replacemnts = 5000
-    _personal_dir = os.path.join(gaupol.PROFILE_DIR, "spell-check")
+    _personal_dir = os.path.join(gaupol.CONFIG_HOME_DIR, "spell-check")
 
     def __init___require(self, parent, application):
         assert gaupol.util.enchant_available()
@@ -111,11 +111,12 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
                     self._new_rows.append(self._row)
                     self._new_texts.append(text)
             # Move to the next row in the current page, move to the next page
-            # in the sequence of target pages or end when all pages checked,
+            # in the sequence of target pages or end when all pages checked.
             try:
                 self._advance_row()
             except StopIteration:
                 try:
+                    # pylint: disable-msg=E1101
                     self._pager.next()
                 except StopIteration:
                     break
@@ -178,7 +179,7 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
     def _init_checker(self):
         """Initialize the checker for conf.spell_check.language.
 
-        Raise ValueError if dictionary initialization fails.
+        Raise ValueError or if dictionary initialization fails.
         """
         import enchant.checker
         language = self.conf.language
@@ -189,9 +190,13 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
                 gaupol.util.print_write_io(sys.exc_info(), path)
                 self._add_button.set_sensitive(False)
                 dict = enchant.Dict(str(language))
+            # Sometimes enchant will initialize a dictionary that will not
+            # actually work when trying to use it, hence check something.
+            dict.check("gaupol")
         except enchant.Error, (message,):
             self._show_error_dialog(message)
-            raise ValueError
+            raise ValueError("Dictionary initialization failed "
+                "for language %s" % repr(language))
         self._checker = enchant.checker.SpellChecker(dict, "")
 
     def _init_fonts(self):
@@ -266,7 +271,8 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
         gaupol.util.makedirs(self._personal_dir)
         self._init_checker()
         self._init_replacements()
-        name = gaupol.locales.code_to_name(self.conf.language)
+        try: name = gaupol.locales.code_to_name(self.conf.language)
+        except LookupError: name = self.conf.language
         self._language_label.set_markup("<b>%s</b>" % name)
 
     def _init_tree_view(self):
@@ -284,7 +290,11 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
         """Add the current word to the user dictionary."""
 
         word = unicode(self._checker.word)
-        self._checker.dict.add_to_pwl(word)
+        # Dict.add_to_pwl is deprecated, please use Dict.add.
+        if hasattr(self._checker, "add"):
+            self._checker.dict.add(word)
+        elif hasattr(self._checker, "add_to_pwl"):
+            self._checker.dict.add_to_pwl(word)
         self._advance()
 
     def _on_edit_button_clicked(self, *args):
@@ -420,7 +430,8 @@ class SpellCheckDialog(gaupol.gtk.GladeDialog):
     def _show_error_dialog(self, message):
         """Show an error dialog after failing to load dictionary."""
 
-        name = gaupol.locales.code_to_name(self.conf.language)
+        try: name = gaupol.locales.code_to_name(self.conf.language)
+        except LookupError: name = self.conf.language
         title = _('Failed to load dictionary for language "%s"') % name
         dialog = gaupol.gtk.ErrorDialog(self._dialog, title, message)
         dialog.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
