@@ -14,20 +14,13 @@
 # You should have received a copy of the GNU General Public License along with
 # Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
+import codecs
 import gaupol
 _ = gaupol.i18n._
 
 
 class TestModule(gaupol.TestCase):
 
-    def test__translate_code(self):
-
-        translate_code = gaupol.encodings._translate_code
-        assert translate_code("johab") == "johab"
-        assert translate_code("UTF-8") == "utf_8"
-        assert translate_code("ISO-8859-1") == "latin_1"
-        self.raises(ValueError, translate_code, "xxxxx")
-
     def test_code_to_description(self):
 
         code_to_description = gaupol.encodings.code_to_description
@@ -58,11 +51,62 @@ class TestModule(gaupol.TestCase):
 
     def test_detect__value_error(self):
 
-        translate_code = gaupol.encodings._translate_code
+        translate_code = gaupol.encodings.translate_code
         def bad_translate_code(code): raise ValueError
-        gaupol.encodings._translate_code = bad_translate_code
+        gaupol.encodings.translate_code = bad_translate_code
         assert gaupol.encodings.detect(self.get_subrip_path()) is None
-        gaupol.encodings._translate_code = translate_code
+        gaupol.encodings.translate_code = translate_code
+
+    def test_detect_bom__none(self):
+
+        path = self.get_subrip_path()
+        encoding = gaupol.encodings.detect_bom(path)
+        assert encoding is None
+
+    def test_detect_bom__utf_8(self):
+
+        path = self.get_subrip_path()
+        text = open(path, "r").read()
+        open(path, "w").write(codecs.BOM_UTF8 + text)
+        encoding = gaupol.encodings.detect_bom(path)
+        if gaupol.encodings.is_valid_code("utf_8_sig"):
+            assert encoding == "utf_8_sig"
+
+    def test_detect_bom__utf_16_be(self):
+
+        path = self.get_subrip_path()
+        text = open(path, "r").read()
+        open(path, "w").write(codecs.BOM_UTF16_BE + text)
+        encoding = gaupol.encodings.detect_bom(path)
+        if gaupol.encodings.is_valid_code("utf_16_be"):
+            assert encoding == "utf_16_be"
+
+    def test_detect_bom__utf_16_le(self):
+
+        path = self.get_subrip_path()
+        text = open(path, "r").read()
+        open(path, "w").write(codecs.BOM_UTF16_LE + text)
+        encoding = gaupol.encodings.detect_bom(path)
+        if gaupol.encodings.is_valid_code("utf_16_le"):
+            assert encoding == "utf_16_le"
+
+    def test_detect_bom__utf_32_be(self):
+
+        path = self.get_subrip_path()
+        text = open(path, "r").read()
+        open(path, "w").write(codecs.BOM_UTF32_BE + text)
+        encoding = gaupol.encodings.detect_bom(path)
+        if gaupol.encodings.is_valid_code("utf_32_be"):
+            assert encoding == "utf_32_be"
+
+    def test_detect_bom__utf_32_le(self):
+
+        path = self.get_subrip_path()
+        text = open(path, "r").read()
+        open(path, "w").write(codecs.BOM_UTF32_LE + text)
+        encoding = gaupol.encodings.detect_bom(path)
+        if gaupol.encodings.is_valid_code("utf_32_le"):
+            assert encoding == "utf_32_le"
 
     def test_get_locale_code(self):
 
@@ -105,3 +149,11 @@ class TestModule(gaupol.TestCase):
         assert name_to_code("GB2312") == "gb2312"
         assert name_to_code("PTCP154") == "ptcp154"
         self.raises(ValueError, name_to_code, "XXXXX")
+
+    def test_translate_code(self):
+
+        translate_code = gaupol.encodings.translate_code
+        assert translate_code("johab") == "johab"
+        assert translate_code("UTF-8") == "utf_8"
+        assert translate_code("ISO-8859-1") == "latin_1"
+        self.raises(ValueError, translate_code, "xxxxx")
