@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Osmo Salomaa
+# Copyright (C) 2007-2008 Osmo Salomaa
 #
 # This file is part of Gaupol.
 #
@@ -9,22 +9,24 @@
 #
 # Gaupol is distributed in the hope that it will be useful, but WITHOUT ANY
 # WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
-# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License along with
-# Gaupol.  If not, see <http://www.gnu.org/licenses/>.
+# Gaupol. If not, see <http://www.gnu.org/licenses/>.
 
 import gaupol
-_ = gaupol.i18n._
-
-from gaupol import unittest
-from .. import scripts
 
 
-class TestModule(unittest.TestCase):
+class TestModule(gaupol.TestCase):
 
     def test_code_to_name(self):
 
-        assert scripts.code_to_name("Arab") == _("Arabic")
-        assert scripts.code_to_name("Cher") == _("Cherokee")
-        assert scripts.code_to_name("Latn") == _("Latin")
+        name = gaupol.i18n.dgettext("iso_15924", "Arabic")
+        assert gaupol.scripts.code_to_name("Arab") == name
+        name = gaupol.i18n.dgettext("iso_15924", "Latin")
+        assert gaupol.scripts.code_to_name("Latn") == name
+
+    def test_is_valid(self):
+
+        assert gaupol.scripts.is_valid("Latn")
+        assert not gaupol.scripts.is_valid("Xxxx")
